Index: src/Parameters/Specifics/Value_elements.cpp
===================================================================
--- src/Parameters/Specifics/Value_elements.cpp	(revision 917c4614b3ea55896fe148578f4fe572d88788a4)
+++ src/Parameters/Specifics/Value_elements.cpp	(revision c4c113f2b27d48f3fec4e388d1907885b72acf87)
@@ -22,5 +22,5 @@
 
 /*
- * Value_elementss.cpp
+ * Value_elements.cpp
  *
  *  Created on: Jul 18, 2015
Index: src/Parameters/Value.hpp
===================================================================
--- src/Parameters/Value.hpp	(revision 917c4614b3ea55896fe148578f4fe572d88788a4)
+++ src/Parameters/Value.hpp	(revision c4c113f2b27d48f3fec4e388d1907885b72acf87)
@@ -118,10 +118,11 @@
 };
 
-#include "Value_impl.hpp"
-
 #include "Specifics/Value_atom.hpp"
 #include "Specifics/Value_element.hpp"
+#include "Specifics/Value_elements.hpp"
 #include "Specifics/Value_molecule.hpp"
 #include "Specifics/Value_string.hpp"
 
+#include "Value_impl.hpp"
+
 #endif /* VALUE_HPP_ */
Index: tests/CodeChecks/testsuite-specifics_present_in_value_header.at
===================================================================
--- tests/CodeChecks/testsuite-specifics_present_in_value_header.at	(revision c4c113f2b27d48f3fec4e388d1907885b72acf87)
+++ tests/CodeChecks/testsuite-specifics_present_in_value_header.at	(revision c4c113f2b27d48f3fec4e388d1907885b72acf87)
@@ -0,0 +1,42 @@
+#
+#    MoleCuilder - creates and alters molecular systems
+#    Copyright (C) 2017 Frederik Heber
+#
+#    This program is free software: you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation, either version 3 of the License, or
+#    (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
+#
+#    You should have received a copy of the GNU General Public License
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+AT_SETUP([Checking for every specific Value impl present in value header])
+AT_KEYWORDS([CodeCheck value header specific])
+ok=
+echo `pwd`
+echo "${#ok[*]} are ok to not appear in userguide: ${ok[*]}."
+liste=`find ${abs_top_srcdir}/src/Parameters/Specifics -name 'Value*.hpp' | sed -e "s#.*/src/Parameters/\(Specifics.*\)#\1#"`
+for token in $liste
+do
+  # check whether its one of the excluded ones
+  found=0
+  for item in $ok
+  do
+    if test "$item" == "`$token`"
+    then
+      found=1
+      break
+    fi
+  done
+  # if not, check whether it contains the include
+  if test $found -eq 0
+  then
+    AT_CHECK([egrep -q $token ${abs_top_srcdir}/src/Parameters/Value.hpp], 0, [ignore], [ignore], [echo "Could not find $token include in Value.hpp."])
+  fi
+done
+AT_CLEANUP
Index: tests/CodeChecks/testsuite.at
===================================================================
--- tests/CodeChecks/testsuite.at	(revision 917c4614b3ea55896fe148578f4fe572d88788a4)
+++ tests/CodeChecks/testsuite.at	(revision c4c113f2b27d48f3fec4e388d1907885b72acf87)
@@ -45,2 +45,4 @@
 
 m4_include(testsuite-action_present_in_userguide.at)
+
+m4_include(testsuite-specifics_present_in_value_header.at)

Index: src/Parameters/Specifics/Value_elements.hpp
===================================================================
--- src/Parameters/Specifics/Value_elements.hpp	(revision 917c4614b3ea55896fe148578f4fe572d88788a4)
+++ src/Parameters/Specifics/Value_elements.hpp	(revision c4c113f2b27d48f3fec4e388d1907885b72acf87)
@@ -1,4 +1,4 @@
 /*
- * Value_element.hpp
+ * Value_elements.hpp
  *
  *  Created on: Sep 10, 2014
@@ -6,6 +6,6 @@
  */
 
-#ifndef VALUE_ELEMENT_HPP_
-#define VALUE_ELEMENT_HPP_
+#ifndef VALUE_ELEMENTS_HPP_
+#define VALUE_ELEMENTS_HPP_
 
 // include config.h
@@ -19,15 +19,15 @@
 #include "Parameters/Value.hpp"
 
 // This overrides string conversions for the type element which need a specific function call.
 
 template <>
-bool Value<const element *>::isValidAsString(const std::string &_value) const throw(ParameterValidatorException);
+bool Value<std::vector<const element *> >::isValidAsString(const std::string &_value) const throw(ParameterValidatorException);
 
 template <>
-const std::string Value<const element *>::getAsString() const throw(ParameterValueException);
+const std::string Value<std::vector<const element *> >::getAsString() const throw(ParameterValueException);
 
 template <>
-void Value<const element *>::setAsString(const std::string &_value) throw(ParameterException);
+void Value<std::vector<const element *> >::setAsString(const std::string &_value) throw(ParameterException);
 
 
-#endif /* VALUE_ELEMENT_HPP_ */
+#endif /* VALUE_ELEMENTS_HPP_ */
@@ -19,15 +19,15 @@
 #include "Parameters/Value.hpp"
 
-// This overrides string conversions for the type element which need a specific function call.
+// This overrides string conversions for the type vector<element> which need a specific function call.
 
 template <>